Cosmetics.
[selector.git] / mkdeb.sh
index 55ef95e..291c677 100755 (executable)
--- a/mkdeb.sh
+++ b/mkdeb.sh
@@ -1,8 +1,8 @@
 #!/bin/bash
 
 #
#  selector is a simple shell command for selection of strings with a
#  dynamic pattern-matching.
 #
 #  Copyright (c) 2009 Francois Fleuret
 #  Written by Francois Fleuret <francois@fleuret.org>
@@ -47,11 +47,11 @@ Version: ${VERSION}
 Maintainer: Francois Fleuret <francois@fleuret.org>
 Architecture: i386
 Depends: ${LIB_DEPENDS}
-Description: A command line for dynamic string-matching
- This is a command line for dynamic string selection. As you type a
- list of substrings separated by ';', or a regexp, the display is
- updated in real time to show only the matching lines. The main usage
- of selector is as an efficient search in the shell command
+Description: A command line utility for dynamic string-matching
+ This is a command line utility for dynamic string selection. As you
+ type a list of substrings separated by ';', or a regexp, the display
+ is updated in real time to show only the matching lines. The main
usage of selector is as an efficient search in the shell command
  history. With the correct option, it will inject the selected line
  into the tty input buffer, hence allowing the user to edit the line
@@ -1,8 +1,8 @@
 
 #
-#  selector is a simple shell command for selection of strings with a
-#  dynamic pattern-matching.
+#  selector is a simple command line utility for selection of strings
+#  with a dynamic pattern-matching.
 #
 #  Copyright (c) 2009 Francois Fleuret
  and execute it as a standard command.